pub struct DragSourceEnter;Expand description
Receives DragSourceEvent::Enter — sent to the element being dragged when it enters
a potential drop target. other_element identifies the drop target that was entered.
Routing
Dispatched to Target phase only on the dragged element.
Default Actions
No preventable default action.