pub struct DragSourceLeave;Expand description
Receives DragSourceEvent::Leave — sent to the element being dragged when it leaves
a potential drop target. other_element identifies the drop target that was left.
Routing
Dispatched to Target phase only on the dragged element.
Default Actions
No preventable default action. Note: disabled views can still receive this event to clean up internal drag state if the view was disabled mid-drag.