pub struct DragStart;Expand description
Receives DragSourceEvent::Start — sent to the element being dragged when the drag
begins (pointer has moved beyond the drag threshold while a button is held down).
Routing
Dispatched to Target phase only on the dragged element.
Default Actions
No preventable default action.