pub struct DragTargetEnter;Expand description
Receives DragTargetEvent::Enter — sent to a drop target when a dragged element enters
its bounds. other_element identifies the element being dragged.
Routing
Dispatched to Target phase only on the drop target element.
Default Actions
No preventable default action.