pub struct DragTargetLeave;Expand description
Receives DragTargetEvent::Leave — sent to a drop target when a dragged element
leaves its bounds. other_element identifies the element being dragged.
Routing
Dispatched to Target phase only on the drop target element.
Default Actions
No preventable default action.