pub struct ThemeChanged;Expand description
Receives Event::Window ThemeChanged variant — fired when the system theme changes
(e.g., light to dark mode).
Routing
Dispatched to Target phase only on all views that have registered this listener. Views that do not register a listener do not receive window events.
Default Actions
No preventable default action.