pub struct UpdatePhaseBoxTreeCommit;Expand description
Receives Event::Window(UpdatePhase(BoxTreeCommit)) — fired when box tree changes are
being committed (finalized before painting).
Routing
Dispatched to Target phase only on all views that have registered this listener. Not all phases run every cycle; a single phase may run multiple times per cycle.
Default Actions
No preventable default action.