pub struct UpdatePhaseBoxTreePendingUpdates;Expand description
Receives Event::Window(UpdatePhase(BoxTreePendingUpdates)) — fired when incremental
box tree changes for specific views are being processed.
Routing
Dispatched to Target phase only on all views that have registered this listener. Not all phases run every cycle; a single phase may run multiple times per cycle.
Default Actions
No preventable default action.