pub struct UpdatePhasePaintPresent;Expand description
Receives Event::Window(UpdatePhase(PaintPresent)) — fired when the entire update cycle
is complete and the window is ready for painting if needed.
Routing
Dispatched to Target phase only on all views that have registered this listener. Not all phases run every cycle; a single phase may run multiple times per cycle.
Default Actions
No preventable default action.