pub struct UpdatePhaseStyle;Expand description
Receives Event::Window(UpdatePhase(Style)) — fired during the style resolution phase.
Routing
Dispatched to Target phase only on all views that have registered this listener. Not all phases run every cycle; a single phase may run multiple times per cycle.
Default Actions
No preventable default action.